/*
 * Copyright (C) 1991-1998 Erik Schoenfelder (schoenfr@gaertner.de)
 *
 * This file is part of NASE A60.
 * 
 * NASE A60 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * NASE A60 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with NASE A60; see the file COPYING.  If not, write to the Free
 * Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * version.h					Aug '90
 *						Jul '14
 *
 * Erik Schoenfelder (schoenfr@web.de)
 */

#ifndef VERSION_H_HOOK
#define VERSION_H_HOOK


#define VERSION         "NASE A60  Version v0.23a"


#endif /* VERSION_H_HOOK */
